/***************************************************************************
 *   Copyright (C) 2001,2002,2003,2004,2005,2006,2007,2008,2009            *
 *   by Rick L. Vinyard, Jr.                                               *
 *   rvinyard@cs.nmsu.edu                                                  *
 *                                                                         *
 *   This file is part of the conexus library.                             *
 *                                                                         *
 *   The conexus library is free software; you can redistribute it and/or  *
 *   modify it under the terms of the GNU General Public License           *
 *   version 3 as published by the Free Software Foundation.               *
 *                                                                         *
 *   The conexus library is distributed in the hope that it will be        *
 *   useful, but WITHOUT ANY WARRANTY; without even the implied warranty   *
 *   of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU   *
 *   General Public License for more details.                              *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this software. If not see <http://www.gnu.org/licenses/>.  *
 ***************************************************************************/
#ifndef CONEXUS_UTILITY_H
#define CONEXUS_UTILITY_H

#include <conexus/factory.h>
#include <conexus/registry.h>

namespace Conexus {

  bool use_dispatcher_default();

  void set_use_dispatcher_default( bool use_dispatcher_default=true );

  /**
   * The init method should be called before any conexus servers are started.
   *
   * Generally it is a good idea to call this at the beginning of your program if you are
   * going to use the conexus servers.
   *
   * @param use_dispatcher_default If true, dispatchers will be used by default for
   * multi-threaded callbacks. For use in Gtk, Gtkmm or any other environment that needs
   * callbacks to occur in a main thread this is a good idea. Handling of the incoming data
   * will remain multi-threaded, and queued by the thread. Only data dispatching will return
   * to the single threaded model if use_dispatcher_default is true.
   *
   * @param init_dbus If conexus was built with dbus support and this parameter is true
   * DBus::init() will be called. If conexus was not built with dbus support the value
   * of this parameter does not matter.
   */
  void init( bool use_dispatcher_default=false, bool init_dbus=true );

  bool initialized();

  void set_default_multicast_hop_limit( unsigned hop_limit );

  void enable_default_multicast_loopback( bool enable=true );

  extern Factory::pointer __default_factory;

  Factory& default_factory();

  bool set_default_factory( Factory::pointer new_factory );

  extern Registry::pointer __default_registry;

  Registry& default_registry();

  bool set_default_registry( Registry::pointer new_registry );
}

#endif
